translate.misc.sparse.ParserError

Package translate :: Package misc :: Module sparse :: Class ParserError |
[hide private]
[frames] | no frames]

# Class ParserError

source code

Intelligent parser error

Instance Methods | [hide private]
__init__(self, parser, message, tokennum) takes a message and the number of the token that caused the error | source code
Inherited from `exceptions.ValueError`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, parser, message, tokennum) (Constructor) | source code
takes a message and the number of the token that caused the error Overrides: object.__init__